/*
 *      tabwidget.h
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef TABWIDGET_H
#define TABWIDGET_H

#include <QListWidget>
#include <QStackedWidget>
#include <QSplitter>

class TabWidget : public QWidget
{
    Q_OBJECT
public:
    explicit TabWidget(QWidget *parent = 0);

    void setTabTextColor(int index, const QColor &color);
    QColor tabTextColor(int index) const;

    QWidget *currentWidget() const;
    void setCurrentWidget(QWidget *widget);
    int indexOf(QWidget *w) const;
    int currentIndex() const;
    int count() const;
    QWidget *widget(int index) const;
    QString tabText(int index) const;
    void setTabText(int index, const QString &label);
    int addTab(QWidget *page, const QString &label);
    int addTab(QWidget *page, const QIcon &icon, const QString &label);
    void setTabIcon(int index, const QIcon &icon);
    void setCurrentIndex(int index);
    int insertTab(int index, QWidget *page, const QString &label);
    int insertTab(int index, QWidget *page, const QIcon &icon, const QString &label);
    QIcon tabIcon(int index) const;
    void removeTab(int index);
private:
    QSplitter *m_splitter;
    QListWidget *m_navigation;
    QStackedWidget *m_switcher;
private slots:
    void slotRowChanged(int);
signals:
    void currentChanged(int);
};

#endif // TABWIDGET_H
